==> qtcreator_4.11.0.orig.tar.xz: qt-creator-opensource-src-4.11.0/src/plugins/clangtools/runsettingswidget.h <==
/****************************************************************************
**
** Copyright (C) 2019 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <cpptools/clangdiagnosticconfig.h>

#include <QWidget>

namespace ClangTools {
namespace Internal {

class RunSettings;

namespace Ui {
class RunSettingsWidget;
}

class RunSettingsWidget : public QWidget
{
    Q_OBJECT

public:
    explicit RunSettingsWidget(QWidget *parent = nullptr);
    ~RunSettingsWidget();

    void fromSettings(const RunSettings &s);
    RunSettings toSettings() const;

signals:
    void diagnosticConfigsEdited(const CppTools::ClangDiagnosticConfigs &configs);
    void changed();

private:
    Ui::RunSettingsWidget *m_ui;
};

} // namespace Internal
} // namespace ClangTools

==> qtcreator_4.14.1.orig.tar.xz: qt-creator-opensource-src-4.14.1/src/plugins/clangtools/runsettingswidget.h <==
/****************************************************************************
**
** Copyright (C) 2019 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <cpptools/clangdiagnosticconfig.h>

#include <QWidget>

namespace CppTools {
class ClangDiagnosticConfigsSelectionWidget;
}

namespace ClangTools {
namespace Internal {

class RunSettings;

namespace Ui {
class RunSettingsWidget;
}

class RunSettingsWidget : public QWidget
{
    Q_OBJECT

public:
    explicit RunSettingsWidget(QWidget *parent = nullptr);
    ~RunSettingsWidget();

    CppTools::ClangDiagnosticConfigsSelectionWidget *diagnosticSelectionWidget();

    void fromSettings(const RunSettings &s);
    RunSettings toSettings() const;

signals:
    void changed();

private:
    Ui::RunSettingsWidget *m_ui;
};

} // namespace Internal
} // namespace ClangTools
